@@ -15,7 +15,8 @@ sub store($c) {
   if ($c->current_route =~ /^api\./) {    #invoked via OpenAPI
     $c->openapi->valid_input or return;
     my $in = $c->validation->output;
-    @$in{qw(user_id group_id)} = ($user->{id}, $user->{group_id});
+    @$in{qw(user_id group_id changed_by)}
+      = ($user->{id}, $user->{group_id}, $user->{id});
     my $id = $c->stranici->add($in);
     $c->res->headers->location(
                         $c->url_for("api.show_stranici", id => $id)->to_string);
@@ -24,7 +25,6 @@ sub store($c) {
 
   # 1. Validate input
   my $v = $c->_validation;
-  $c->debug('failed:', $v->failed);
   return $c->render(action => 'create', stranici => {}) if $v->has_error;
 
   # 2. Insert it into the database
@@ -43,7 +43,11 @@ sub store($c) {
 # GET /stranici/:id/edit
 # Display form for edititing resource in table stranici.
 sub edit($c) {
-  return $c->render(stranici => $c->stranici->find($c->param('id')));
+
+  #TODO: implement language switching based on Ado::L18n
+  my $l = $c->param('language') || $c->config('default_language');
+  my $stranici = $c->stranici->find_for_edit($c->stash('id'), $l);
+  return $c->render(stranici => $stranici);
 }
 
 # PUT /stranici/:id
@@ -51,12 +55,12 @@ sub edit($c) {
 sub update($c) {
 
   # Validate input
-  my $validation = $c->_validation;
-  return $c->render(action => 'edit', stranici => {}) if $validation->has_error;
+  my $v = $c->_validation;
+  return $c->render(action => 'edit', stranici => {}) if $v->has_error;
 
   # Update the record
   my $id = $c->param('id');
-  $c->stranici->save($id, $validation->output);
+  $c->stranici->save($id, $v->output);
 
   # Redirect to the updated record or just send "204 No Content"
   # See https://developer.mozilla.org/docs/Web/HTTP/Status/204
@@ -114,31 +118,31 @@ sub remove($c) {
 
 # Validation for actions that store or update
 sub _validation($c) {
+  $c->req->param(alias => $c->param('title')) unless $c->param('alias');
   my $v = $c->validation;
 
   # Add validation rules for the record to be stored in the database
-  $v->required('id') if $c->stash->{action} ne 'store';
   $v->optional('pid',    'trim')->like(qr/^\d+$/);
   $v->optional('dom_id', 'trim')->like(qr/^\d+$/);
-  $v->required('alias',     'trim')->size(0, 32);
+  $v->required('alias', 'slugify')->size(0, 32);
   $v->required('page_type', 'trim')->size(0, 32);
   $v->optional('sorting',     'trim')->like(qr/^\d+$/);
   $v->optional('template',    'trim')->size(0, 255);
-  $v->optional('permissions', 'trim')->size(0, 10);
+  $v->optional('permissions', 'trim')->like(qr/^[dlrwx\-]{10}$/);
   $v->optional('user_id',     'trim')->like(qr/^\d+$/);
   $v->optional('group_id',    'trim')->like(qr/^\d+$/);
   $v->optional('tstamp',      'trim')->like(qr/^\d+$/);
   $v->optional('start',       'trim')->like(qr/^\d+$/);
   $v->optional('stop',        'trim')->like(qr/^\d+$/);
-  $v->optional('published',   'trim')->like(qr/^\d+$/);
-  $v->optional('hidden',      'trim')->like(qr/^\d+$/);
-  $v->optional('deleted',     'trim')->like(qr/^\d+$/);
-  $v->optional('changed_by',  'trim')->like(qr/^\d+$/);
+  $v->optional('published',   'trim')->in(2, 1, 0);
+  $v->optional('hidden',  'trim')->in(1, 0);
+  $v->optional('deleted', 'trim')->in(1, 0);
+  $v->optional('changed_by', 'trim')->like(qr/^\d+$/);
 
   # Page attributes
   $v->required('title', 'xml_escape', 'trim')->size(3, 32);
-  $v->optional('body', 'trim');
-
+  $v->optional('body',     'trim');
+  $v->optional('title_id', 'trim')->like(qr/^\d+$/);
   $v->required('language', 'trim')->size(5, 5);
   return $v;
 }
